Module commit

Module commit 

Provide multiple traversal implementations with different performance envelopes.

Use Simple for fast walks that maintain minimal state, or Topo for a more elaborate traversal.

Modules

simple
Simple ancestors traversal, without the need to keep track of graph-state.
topo
Topological commit traversal, similar to git log --topo-order, which keeps track of graph state.

Structs

Info
Information about a commit that we obtained naturally as part of the iteration.
Simple
A fast iterator over the ancestors of one or more starting commits.
Topo
A commit walker that walks in topographical order, like git rev-list --topo-order or --date-order depending on the chosen topo::Sorting.

Enums

Either
Information about a commit that can be obtained either from a gix_object::CommitRefIter or a gix_commitgraph::file::Commit.
Parents
Specify how to handle commit parents during traversal.

Functions

find
Find information about a commit by either getting it from a gix_commitgraph::Graph, if present, or a gix_object::CommitRefIter otherwise.

Type Aliases

ParentIds
The collection of parent ids we saw as part of the iteration.